---
layout: post
name: 'The convergence of AI, Blockchain and Privacy'
title: 'The convergence of AI, Blockchain and Privacy'
date: 2024-03-22 00:00:00
authors: [guru]
published: true
slug: convergence-of-ai-blockchain-privacy
categories: waku, ideas
image: /img/ai-waku.png
---

An overview of the need for decentralised and privacy-preserving artificial intelligence.

<!--truncate-->

---

<figure>
    <img src="/img/ai-waku.png"
         alt="header-image" />
    <figcaption>Image generated with MidJourney</figcaption>
</figure>

<br />
After the recent boom in the generative artificial intelligence (AI) space, several critics have questioned the convergence of AI and web3. There is also a growing misconception that web3 does not have native use cases within the AI space. Indeed, some are popularising an unfounded argument that web3 is being forced into the AI space. This blog post will explore the need for an intersection between these cutting-edge technologies and some potential use cases where we can implement a technology like [Waku](https://waku.org/) in AI-related areas.


## The need for an intersection between AI and web3

I have always believed that web3 is not 'just' about blockchains but extends to the broader idealogy of building censorship-resistant infrastructure with privacy-preserving technologies.

We often only understand the need for such ethos once we get exposed to the problems that hinder innovation through censorship. A perfect example of this scenario is a recent [statement from an Indian government official](https://timesofindia.indiatimes.com/gadgets-news/government-to-tech-companies-take-permission-before-launching-ai-models-in-india/articleshow/108167769.cms).

The government official stated that with new regulations and compliance requirements faced by the artificial intelligence space, GenAI domain experts are looking to web3 for solutions. AI innovators are turning to permissionless and privacy-preserving technologies to distribute their model deployments and avoid being censored.


## The role of a privacy-preserving communications protocol in AI

Communication is one of the most important aspects of any application or service that uses any generative AI model. This is to solve the problem of censorship and safeguard user data from mass surveillance attacks.


### **Why privacy-preserving communications over traditional web2 communications?**

The AI space proposes a vast and unspoken risk of mass surveillance attacks. Centralised LLMs can log your prompts and identity in the pretext of data analytics and reinforcement learning. This means that the centralised stakeholders know about the conversations between you and your AI agent.

It gets even scarier when we think about the potential attacks that can be carried out with this data. Your AI agents can use critical information, such as your health conditions, to carry out targeted advertisements or data harvesting.


### **How can Waku impact communications in the AI space?**

[Waku](https://waku.org/) is a decentralised and privacy-preserving communications protocol that can be used to build securely scalable and robust communication between different nodes.

Waku has a huge potential to create an everlasting impact on the AI space. Waku can help AI projects fill up some of the most crucial technical gaps:


1. Decoupling identity from data

    Understandably, AI projects have the potential to generate massive amounts of data that can be useful in areas like big data analysis, analytics and reinforcement training. However, storing data sourced by an AI model can pose a considerable risk as the user's identity will be linked with their particular prompts. For example, a centralised LLM platform should be able to know about the critical health-related prompts that you search for.

2. By knowing the identity of a prompt, users are vulnerable to mass surveillance that can result in targeted advertising, social engineering and other attacks.

    With a technology like Waku, decoupling the identity from the prompts is possible. All data generated from LLMs and GenAI models will be anonymous and private.

3. Censorship

    Centralised gatekeepers can block traffic from a specific country or geographic/cultural/economic identity. By using Waku, a project cannot resolve the IP address of a message sender or receiver. The identity of every node in the network is dynamic. It can not reveal any geographic or cultural information, making it impossible for gatekeepers to ban a specific group of users.

4. Data security at its best

    Waku provides flexibility for projects to choose their cryptographic encryption standard. This enables developers to build secure communication channels that do not force a specific type of encryption.

5. Federated Learning Networks

    Waku can facilitate communication and data sharing among edge devices participating in federated learning networks. It can ensure privacy by enabling encrypted communication channels between devices, allowing them to collaborate on model training tasks without revealing sensitive data since the communication channels are built without revealing.

6. Decentralised AI Governance

    Waku can facilitate decentralised governance mechanisms for AI systems, allowing stakeholders to participate in decision-making processes while maintaining privacy and transparency. This could be particularly useful in ensuring fairness, accountability, and transparency in AI systems.

7. Privacy-Preserving Data Labeling

    An essential component of training AI models is data labelling. Waku can be used to crowdsource data labelling tasks while preserving the privacy of the labelled data. Workers can contribute labels without directly accessing the underlying data, mitigating privacy risks.

8. Decentralised Governance models for AI

    Waku can facilitate decentralised governance mechanisms for AI systems, allowing stakeholders to participate in decision-making processes while maintaining privacy and transparency. This could be particularly useful in ensuring fairness, accountability, and transparency in AI systems.

9. DOS Protection for APIs

    With Waku's Rate Limiting Nullifiers (RLN), it is possible to implement economic rate limiting for the API endpoints. Denial of Service (DoS) attacks cannot exploit the LLM models. Exposing an API endpoint without a proper rate-limiting mechanism can lead to service outages or unintended computation expenses.


### **Some closing words**

The use cases mentioned above are just a few examples of where Waku can add value within the AI space. So many areas are yet to be explored, and the Waku team is on hand to help AI projects integrate a privacy-preserving communications infrastructure. [Reach out to the Waku team](https://discord.waku.org/) if you want to learn more!

